==> m-tx_0.30a.orig.tar.gz: m-tx-0.30a.orig/doc/volta.ex <==
%%%%%%%%%%%%%%%%%
%
% volta.tex
%
%%%%%%%%%%%%%%%%
\smallmusicsize%
\tracingstats=2\relax
\hsize=524pt
\vsize=740pt
\def\nbinstruments{1}
\setstaffs11
\setclef10
\setname1{ }
\generalsignature{ 0}%
\generalmeter{\meterfrac{4}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\nostartrule
\staffbotmarg6\Interligne%
\setsize1{\normalvalue}%
\setsongraise1{0\internote}%
\startpiece\addspace\afterruleskip%            
\setlyrics{11}{Now to learn this vol-ta thing, lead up to the first end-ing.}%
\assignlyrics1{11}%
\auxlyr{\assignlyrics1{}}%
\setsongraise1{4\internote}%
\znotes\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTesp{\vnotes3.46\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\advance\barno-1\leftrepeat
\NOTes\qu c\qu c\qu g\qu g\en%
% bar  2
\xbar
\NOTes\qu{'a}\qu a\en%
\NOTEs\hu g\en%
% bar  3
\xbar
\NOTes\qu f\qu f\qu e\qu e\en%
% bar  4
\Setvolta1%
\xbar
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\setlyrics{11}{next end-ing.}%
% bar  5
\setrightrepeat
\endvoltabox
\Setvolta2%
\alaligne
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\setlyrics{11}{Try to write a }%
\setlyrics{12}{Try to learn more}%
\assignlyrics1{11,12}%
% bar  6
\setleftrepeat
\endvolta
\xbar
\NOTes\qu g\qu g\qu f\qu f\en%
\setlyrics{11}{sim-ple text    P-M-X.  }%
\assignlyrics1{11}%
% bar  7
\Setvolta1%
\xbar
\NOTes\qu e\qu e\en%
\NOTEs\hu d\en%
% bar  8
\setrightrepeat
\endvoltabox
\Setvolta2%
\xbar
\NOTes\qu e\qu e\en%
\NOTEs\hu d\en%
\setlyrics{11}{Now it's time to end the test, so I wish you all the best! }%
% bar  9
\endvolta
\alaligne
\NOTes\qu c\qu c\qu g\qu g\en%
% bar 10
\xbar
\NOTes\qu{'a}\qu a\en%
\NOTEs\hu g\en%
% bar 11
\xbar
\NOTes\qu f\qu f\qu e\qu e\en%
% bar 12
\xbar
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\Endpiece

==> m-tx_0.52.orig.tar.gz: m-tx-0.52/doc/volta.ex <==
%%%%%%%%%%%%%%%%%
%
% volta.tex
%
%%%%%%%%%%%%%%%%
\def\Lrp#1{\centerbar{\liftpause{#1}}}
\smallmusicsize%
\tracingstats=2\relax
\hsize=524pt
\vsize=740pt
\def\nbinstruments{1}
\setstaffs11
\setclef10
\setname1{ }
\generalsignature{ 0}%
\generalmeter{\meterfrac{4}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\nostartrule
\staffbotmarg6\Interligne%
\setsize1{\normalvalue}%
\startpiece\addspace\afterruleskip%
\setlyrics{11}{Now to learn this vol-ta thing, lead up to the first end-ing.}%
\assignlyrics1{11}%
\setsongraise1{4\internote}%
\znotes\zcharnote{16}{\titles{2.0}{}{0}{}{0}{}{0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\advance\barno-1\leftrepeat
\NOTes\qu c\qu c\qu g\qu g\en%
% bar  2
\xbar
\NOTes\qu{'a}\qu a\en%
\NOTEs\hu g\en%
% bar  3
\xbar
\NOTes\qu f\qu f\qu e\qu e\en%
% bar  4
\Setvolta1%
\xbar
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\setlyrics{11}{next end-ing.}%
% bar  5
\setrightrepeat
\endvoltabox
\Setvolta2%
\alaligne
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\setlyrics{11}{Try to write a }%
\setlyrics{12}{Try to learn more}%
\assignlyrics1{11,12}%
% bar  6
\setleftrepeat
\endvolta
\xbar
\NOTes\qu g\qu g\qu f\qu f\en%
\setlyrics{11}{sim-ple text    P-M-X.  }%
\assignlyrics1{11}%
% bar  7
\Setvolta1%
\xbar
\NOTes\qu e\qu e\en%
\NOTEs\hu d\en%
% bar  8
\setrightrepeat
\endvoltabox
\Setvolta2%
\xbar
\NOTes\qu e\qu e\en%
\NOTEs\hu d\en%
\setlyrics{11}{Now it's time to end the test, so I wish you all the best! }%
% bar  9
\endvolta
\alaligne
\NOTes\qu c\qu c\qu g\qu g\en%
% bar 10
\xbar
\NOTes\qu{'a}\qu a\en%
\NOTEs\hu g\en%
% bar 11
\xbar
\NOTes\qu f\qu f\qu e\qu e\en%
% bar 12
\xbar
\NOTes\qu d\qu d\en%
\NOTEs\hu c\en%
\Endpiece
